@@ -204,7 +204,7 @@ class Builder:
     def parse_param(
         self, name: str, param: inspect.Parameter, help_doc: Optional[str] = None
     ) -> Tuple[List[str], Dict[str, Any]]:
-        """ Parse a single parameter """
+        """Parse a single parameter"""
 
         default = param.default
         annotation = param.annotation
@@ -303,6 +303,13 @@ class Builder:
             ) -> None:
                 if values is None:
                     return
+
+                for arg in values:
+                    if "=" not in arg:
+                        raise argparse.ArgumentTypeError(
+                            "unable to parse value as a key=value pair: %s" % repr(arg)
+                        )
+
                 as_dict: Dict[str, str] = {
                     key_arg(k): val_arg(v) for k, v in (x.split("=", 1) for x in values)
                 }
@@ -416,7 +423,7 @@ class Builder:
     def parse_instance(
         self, inst: Callable, subparser: argparse._SubParsersAction
     ) -> None:
-        """ Expose every non-private callable in a class instance """
+        """Expose every non-private callable in a class instance"""
         for (name, func) in self.get_children(inst, is_callable=True):
             sub = subparser.add_parser(name, help=self.get_help(func))
             add_base(sub)
@@ -517,7 +524,11 @@ def execute_api(api: Any, api_types: List[Any], version: str) -> int:
     builder = Builder(api_types)
     builder.add_version(version)
     builder.parse_api(api)
-    args = builder.parse_args()
+    try:
+        args = builder.parse_args()
+    except argparse.ArgumentTypeError as err:
+        LOGGER.error("unable to parse arguments: %s", err)
+        return 1
 
     if args.verbose == 0:
         logging.basicConfig(level=logging.WARNING)
